@@ -1,14 +1,14 @@
 from glob import glob
 import os
 
+import pkg_resources
+
+from tutor import hooks as tutor_hooks
+
 from .__about__ import __version__
 
-HERE = os.path.abspath(os.path.dirname(__file__))
-
-templates = os.path.join(HERE, "templates")
-
 config = {
-    "add": {
+    "unique": {
         "MYSQL_PASSWORD": "{{ 8|random_string }}",
         "SECRET_KEY": "{{ 20|random_string }}",
         "OAUTH2_SECRET": "{{ 8|random_string }}",
@@ -78,24 +78,82 @@ config = {
     },
 }
 
-hooks = {
-    "build-image": {
-        "ecommerce": "{{ ECOMMERCE_DOCKER_IMAGE }}",
-        "ecommerce-worker": "{{ ECOMMERCE_WORKER_DOCKER_IMAGE }}",
-    },
-    "remote-image": {
-        "ecommerce": "{{ ECOMMERCE_DOCKER_IMAGE }}",
-        "ecommerce-worker": "{{ ECOMMERCE_WORKER_DOCKER_IMAGE }}",
-    },
-    "init": ["mysql", "lms", "ecommerce"],
-}
+# Initialization hooks
+tutor_hooks.Filters.COMMANDS_INIT.add_item((
+    "mysql",
+    ("ecommerce", "tasks", "mysql", "init"),
+))
+tutor_hooks.Filters.COMMANDS_INIT.add_item((
+    "lms",
+    ("ecommerce", "tasks", "lms", "init"),
+))
+tutor_hooks.Filters.COMMANDS_INIT.add_item((
+    "ecommerce",
+    ("ecommerce", "tasks", "ecommerce", "init"),
+))
 
+# Image management
+tutor_hooks.Filters.IMAGES_BUILD.add_item((
+    "ecommerce",
+    ("plugins", "ecommerce", "build", "ecommerce"),
+    "{{ ECOMMERCE_DOCKER_IMAGE }}",
+    (),
+))
+tutor_hooks.Filters.IMAGES_BUILD.add_item((
+    "ecommerce-worker",
+    ("plugins", "ecommerce", "build", "ecommerce-worker"),
+    "{{ ECOMMERCE_WORKER_DOCKER_IMAGE }}",
+    (),
+))
+tutor_hooks.Filters.IMAGES_PULL.add_item((
+    "ecommerce",
+    "{{ ECOMMERCE_DOCKER_IMAGE }}",
+))
+tutor_hooks.Filters.IMAGES_PULL.add_item((
+    "ecommerce-worker",
+    "{{ ECOMMERCE_WORKER_DOCKER_IMAGE }}",
+))
+tutor_hooks.Filters.IMAGES_PUSH.add_item((
+    "ecommerce",
+    "{{ ECOMMERCE_DOCKER_IMAGE }}",
+))
+tutor_hooks.Filters.IMAGES_PUSH.add_item((
+    "ecommerce-worker",
+    "{{ ECOMMERCE_WORKER_DOCKER_IMAGE }}",
+))
 
-def patches():
-    all_patches = {}
-    for path in glob(os.path.join(HERE, "patches", "*")):
-        with open(path) as patch_file:
-            name = os.path.basename(path)
-            content = patch_file.read()
-            all_patches[name] = content
-    return all_patches
+####### Boilerplate code
+# Add the "templates" folder as a template root
+tutor_hooks.Filters.ENV_TEMPLATE_ROOTS.add_item(
+    pkg_resources.resource_filename("tutorecommerce", "templates")
+)
+# Render the "build" and "apps" folders
+tutor_hooks.Filters.ENV_TEMPLATE_TARGETS.add_items(
+    [
+        ("ecommerce/build", "plugins"),
+        ("ecommerce/apps", "plugins"),
+    ],
+)
+# Load patches from files
+for path in glob(
+    os.path.join(
+        pkg_resources.resource_filename("tutorecommerce", "patches"),
+        "*",
+    )
+):
+    with open(path, encoding="utf-8") as patch_file:
+        tutor_hooks.Filters.ENV_PATCHES.add_item((os.path.basename(path), patch_file.read()))
+# Add configuration entries
+tutor_hooks.Filters.CONFIG_DEFAULTS.add_items(
+    [
+        (f"ECOMMERCE_{key}", value)
+        for key, value in config.get("defaults", {}).items()
+    ]
+)
+tutor_hooks.Filters.CONFIG_UNIQUE.add_items(
+    [
+        (f"ECOMMERCE_{key}", value)
+        for key, value in config.get("unique", {}).items()
+    ]
+)
+tutor_hooks.Filters.CONFIG_OVERRIDES.add_items(list(config.get("overrides", {}).items()))
